Struct Graph
Source pub struct Graph<'a> {
pub color: Color,
pub width: Option<i32>,
pub height: Option<i32>,
pub counter: &'a Counter,
pub reference_value: f32,
pub orientation: Orientation,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.